@@ -5,18 +5,20 @@ use strict;
 use warnings;
 use String::Validator::Common ;
 use Regexp::Common qw /net/;
-use Net::DNS;
-use Email::Valid;
-use Email::Address;
+#use Net::DNS;
 
-our $VERSION = '0.98_02';
+our $VERSION = '0.93';
 
 =head1 VERSION
 
-Version 0.98
+Version 0.93
 
 =cut
 
+#use Regexp::Common ;
+use Email::Valid;
+use Email::Address;
+
 sub new {
     my $class = shift ;
     my $self = { @_ } ;
@@ -27,7 +29,6 @@ sub new {
                 { $self->{ max_len } = 64 ; }
 	# allow_ip wont work with fqdn or tldcheck
 	if ( $self->{ allow_ip } ) {
-	    $self->{ mxcheck } = 0 ; 
 		$self->{ fqdn } = 0 ;
 		$self->{ tldcheck } = 0 ;
 		}
@@ -41,11 +42,6 @@ sub new {
 	unless( defined $self->{ tldcheck } ) {
         $switchhash{ '-tldcheck' } = 1 }
     $self->{ switchhash } = \%switchhash ;
-    if( $self->{ mxcheck } ) {
-        $self->{ fqdn } = 1 ; #before mx, must pass fqdn.
-        $self->{ NetDNS } = Net::DNS::Resolver->new;
-        }
-        
     bless $self, $class ;
     return $self ;
 }
@@ -53,7 +49,7 @@ sub new {
 # Email::Valid has very terse error codes.
 # Not an OO method must use &
 sub _expound {
-    my $errors = shift || '';
+    my $errors = shift ;
     my $string = shift ;
     my $expounded = '' ;
     if ( $errors =~ m/fqdn/ ) {
@@ -67,10 +63,6 @@ sub _expound {
         $expounded .=
         'The TLD (Top Level Domain) is not recognized.' ;
         }
-    if ( $errors =~ m/mx/ ) {
-    	$expounded .= "Mail Exchanger for $string " .
-            "is missing from Public DNS. Mail cannot be delivered." ;
-    	}
     return $expounded ;
 }
 
@@ -99,22 +91,20 @@ sub Check{
 		unless ( $self->{ allow_ip } ) {
 			$self->_rejectip() }
 		}
-	# Need maildomain for mxcheck.
-	( my $discard, $self->{maildomain} ) = split( /\@/, $self->{ string } );
-    $self->{maildomain} =~ tr/\>//d ; #clean out unwanted chars.
-    if ( $self->{ mxcheck } ) {
-		if ( $self->{ error } == 0 ) {
-		    my $res = $self->{ NetDNS };
-		    unless ( mx( $res, $self->{ maildomain } ) ) {
-                $self->IncreaseErr( "MX" ) ;
-                $self->{ expounded } = 
-                    &_expound( 'mx', $self->{ maildomain} ) ;
-		    }    
-		}
-    }
+# MXCheck isn't working.
+#     if ( $self->{ mxcheck } ) {
+# 		if ( $self->{ error } == 0 ) {
+#          $switchhash{ '-mxcheck'  } = 1 ;
+#          eval {
+#             Email::Valid->address( %switchhash );
+#             } ;
+#          if ( $@ ne '1' ) { $self->IncreaseErr( "MXCheck Failed $@" ) }
+#         } }
 return $self->{ error } ;
 }
 
+
+
 sub Expound {
     my $self = shift ;
     return $self->{ expounded } ;
@@ -126,12 +116,16 @@ sub Expound {
 
 String::Validator::Email - Check if a string is an email address.
 
+
+
 =head1 SYNOPSIS
 
 String::Validator::Email is part of the String Validator Collection. It will
 check a string against any number of email validation rules, and optionally
 against a second string (as in a confirmation box on a webform).
 
+String::Validator::Email is powered by Email::Valid.
+
 =head1 String::Validator Methods and Usage
 
 Provides and conforms to all of the standard String::Validator methods,
@@ -152,8 +146,8 @@ String::Validator::Common for information on the base String::Validator Class.
 Important notes -- SVE uses Email::Valid, however, tldcheck is defaulted to on.
 The choice to turn tldcheck should be obvious. The fudge and local_rules
 options are specific to aol and compuserve, and are not supported.
-Finally mxcheck is not tried if there is already an error, since Email::Valid's 
-DNS check does not work, that is performed directly through Net::DNS.
+Finally mxcheck is not tried if there is already an error, at present
+mxcheck isn't working and is disabled.
 
 =head2 Expound
 
@@ -169,8 +163,8 @@ for returning to an end user.
 
 =head1 ToDo
 
-The major TO DO items are to replace Email::Valid methods, return an Email::Address object and to use it to create methods for returning information
-from an extended mail string like: Jane Brown <jane.brown@domain.com>.
+The major TO DO items are to fix the the call to (or replace) the Email::Valid mx method, return an Email::Address object and to use it to create methods for returning information
+from an extended mail string like: jane.brown@domain.com.
 
 =head1 AUTHOR
 
